@@ -927,7 +927,30 @@ class BossRemote(Remote):
                 id_list, access_mode,
                 parallel=parallel, **kwargs
             )
+    
+    def create_cutout_to_black(self, resource, resolution, x_range, y_range, z_range, time_range=None):
+        """Post a black cutout to the volume service.
 
+        Args:
+            resource (intern.resource.Resource): Resource compatible with cutout operations.
+            resolution (int): 0 indicates native resolution.
+            x_range (list[int]): x range such as [10, 20] which means x>=10 and x<20.
+            y_range (list[int]): y range such as [10, 20] which means y>=10 and y<20.
+            z_range (list[int]): z range such as [10, 20] which means z>=10 and z<20.
+            time_range (optional [list[int]]): time range such as [30, 40] which means t>=30 and t<40.
+
+        Returns:
+            (): Return type depends on volume service's implementation.
+
+        Raises:
+            RuntimeError when given invalid resource.
+            Other exceptions may be raised depending on the volume service's implementation.
+        """
+        if not resource.valid_volume():
+            raise RuntimeError('Resource incompatible with the volume service.')
+        return self._volume.create_cutout_to_black(
+            resource, resolution, x_range, y_range, z_range, time_range)
+        
     def get_experiment(self, coll_name, exp_name):
         """
         Convenience method that gets experiment resource.
